==> sale-3.5.3.jar: iot/sqls/common/insturctDetailQuery.sql <==
select * from (
                select
                  ti.*,
                  ts.f_operate_date, ---操作时间
                  ts.f_type,         --操作类型
                  ts.f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  '应收:'+convert(varchar(100),ts.f_preamount)+',实收:'+convert(varchar(100),ts.f_collection) f_operator_data
                from t_instruct ti
                       left join t_sellinggas ts on ti.f_data_id = ts.id
                where ti.f_instruct_type='远程充值' or ti.f_instruct_type='远程冲正'
                union all
                select
                  ti.*,
                  tuf.f_open_date f_operate_date, ---操作时间
                  '开户' f_type,         --操作类型
                  ts.f_table_state f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  ts.f_operator+convert(varchar(100),tuf.f_open_date,120)+'对'+tuf.f_user_name+'进行开户操作' f_operator_data  --操作信息
                from t_instruct ti
                       left join t_userfiles ts on ti.f_data_id = ts.f_userfiles_id
                left join t_userinfo tuf on tuf.f_userinfo_id=ts.f_userinfo_id
                where ti.f_instruct_type='远程开户'
                union all
                select
                  ti.*,
                  ts.f_operate_date, ---操作时间
                  ts.f_type,         --操作类型
                  ts.f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  '旧表号:'+ts.f_meternumber_old+',新表号:'+ts.f_meternumber+',补气金额:'+convert(varchar(100),ts.f_remanent_money) f_operator_data
                from t_instruct ti
                       left join t_changetables ts on ti.f_data_id = ts.id
                where ti.f_instruct_type='远程注销'
                union all
                select
                  ti.*,
                  ts.f_operate_date, ---操作时间
                  ts.f_change_type+'调价' f_type,         --操作类型
                  '有效' f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  '旧气价:'+convert(varchar(100),ts.f_oldprice_id)+',新气价:'+convert(varchar(100),ts.f_newprice_id) f_operator_data
                from t_instruct ti
                       left join t_pricechange ts on ti.f_data_id = ts.id
                where ti.f_instruct_type='远程调价'
                union all
                select
                    ti.*,
                    f_instruct_date f_operate_date, ---操作时间
                    f_instruct_title f_type,         --操作类型
                    f_instruct_state f_state,        ---操作状态
                    f_inputtor f_operator,     --操作人
                    '' f_operator_data
                from t_instruct ti
                where ti.f_instruct_type='阀门控制'
                union all
                select
                  ti.*,
                  ti.f_instruct_date f_operate_date, ---操作时间
                  ti.f_instruct_type f_type,         --操作类型
                  '有效' f_state,        ---操作状态
                  ''  f_operator,     --操作人
                  ti.f_instruct_type f_operator_data
                from t_instruct ti
                where ti.f_instruct_type not in ('远程充值','远程冲正','远程开户','远程注销','远程调价','阀门控制')
              ) t
where
  {condition}
order by
  f_instruct_date
desc

==> sale-3.7.1.jar: iot/sqls/common/insturctDetailQuery.sql <==
select * from (
                select
                  ti.*,
                  ts.f_operate_date, ---操作时间
                  ts.f_type,         --操作类型
                  ts.f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  '应收:'+convert(varchar(100),ts.f_preamount)+',实收:'+convert(varchar(100),ts.f_collection) f_operator_data
                from t_instruct ti
                       left join t_sellinggas ts on ti.f_data_id = ts.id
                where (ti.f_instruct_type='远程充值' or ti.f_instruct_type='远程冲正')
                  and f_instruct_title !='补费'
                  and f_instruct_title !='扣费'
                  and f_instruct_title !='换表补气'
                union all
                select
                  ti.*,
                  ts.f_operate_date, ---操作时间
                  ts.f_type,         --操作类型
                  ts.f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  '应收:'+convert(varchar(100),ts.f_pregas)+',实收:'+convert(varchar(100),ts.f_preamount) f_operator_data
                from t_instruct ti
                       left join t_fillgas ts on ti.f_data_id = ts.id
                where (ti.f_instruct_type='远程充值' or ti.f_instruct_type='远程冲正') and (f_instruct_title ='补费' or f_instruct_title ='扣费' or f_instruct_title='换表补气')
                union all
                select
                  ti.*,
                  tuf.f_open_date f_operate_date, ---操作时间
                  '开户' f_type,         --操作类型
                  ts.f_table_state f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  ts.f_operator+convert(varchar(100),tuf.f_open_date,120)+'对'+tuf.f_user_name+'进行开户操作' f_operator_data  --操作信息
                from t_instruct ti
                       left join t_userfiles ts on ti.f_data_id = ts.f_userfiles_id
                left join t_userinfo tuf on tuf.f_userinfo_id=ts.f_userinfo_id
                where ti.f_instruct_type='远程开户'
                union all
                select
                  ti.*,
                  ts.f_operate_date, ---操作时间
                  ts.f_type,         --操作类型
                  ts.f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  '旧表号:'+ts.f_meternumber_old+',新表号:'+ts.f_meternumber+',补气金额:'+convert(varchar(100),ts.f_remanent_money) f_operator_data
                from t_instruct ti
                       left join t_changetables ts on ti.f_data_id = ts.id
                where ti.f_instruct_type='远程注销'
                union all
                select
                  ti.*,
                  ts.f_operate_date, ---操作时间
                  ts.f_change_type+'调价' f_type,         --操作类型
                  '有效' f_state,        ---操作状态
                  ts.f_operator,     --操作人
                  '旧气价:'+convert(varchar(100),ts.f_oldprice_id)+',新气价:'+convert(varchar(100),ts.f_newprice_id) f_operator_data
                from t_instruct ti
                       left join t_pricechange ts on ti.f_data_id = ts.id
                where ti.f_instruct_type='远程调价'
                union all
                select
                    ti.*,
                    f_instruct_date f_operate_date, ---操作时间
                    f_instruct_title f_type,         --操作类型
                    f_instruct_state f_state,        ---操作状态
                    f_inputtor f_operator,     --操作人
                    '' f_operator_data
                from t_instruct ti
                where ti.f_instruct_type='阀门控制'
                union all
                select
                  ti.*,
                  ti.f_instruct_date f_operate_date, ---操作时间
                  ti.f_instruct_type f_type,         --操作类型
                  '有效' f_state,        ---操作状态
                  ''  f_operator,     --操作人
                  ti.f_instruct_type f_operator_data
                from t_instruct ti
                where ti.f_instruct_type not in ('远程充值','远程冲正','远程开户','远程注销','远程调价','阀门控制')
              ) t
where
  {condition}
order by
  f_instruct_date
desc
